DS4432

Struct DS4432 

pub struct DS4432<I> { /* private fields */ }
A DS4432 Digital To Analog (DAC) converter on the I2C bus I.

Implementations

Source

impl<I: I2c + ErrorType> DS4432<I>

pub fn new(i2c: I) -> Self

Create a new DS4432 using the given I2C implementation.

Using this constructor doesn’t allow the driver to know the Rfs values so only raw DAC code are supported in the Status.

pub fn with_rfs( i2c: I, rfs0_ohm: Option<u32>, rfs1_ohm: Option<u32>, ) -> Result<Self, I::Error>

Create a new DS4432 using the given I2C implementation and the optinal Rfs values.

If a Rfs value is given for an Output:

  • reading status will automatically convert to microamps value instead of giving the raw DAC code.
  • writing status will allow automatic convertion from microamps value to raw DAC code.

Note: if you want to only deal with raw DAC code, use new instead and use Status::current_ua() to do manual convertion into microamps.

pub fn set_status( &mut self, output: Output, status: Status, ) -> Result<(), I::Error>

Set the current sink/source status and code of an output

pub fn status(&mut self, output: Output) -> Result<Status, I::Error>

Get the current sink/source status and code of an output

pub fn release(self) -> I

Return the underlying I2C device

pub fn destroy(self) -> Self

Destroys this driver and releases the I2C bus I.